# This file was auto-generated by Fern from our API Definition.

import typing

from ..types.empty_block_details import EmptyBlockDetails
from .figure_details import FigureDetailsParams
from .table_cell_details import TableCellDetailsParams
from .table_details import TableDetailsParams

BlockDetailsParams = typing.Union[TableDetailsParams, TableCellDetailsParams, FigureDetailsParams, EmptyBlockDetails]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class FigureDetailsFigureType(enum.StrEnum):
    """
    The refined type of figure - only set when figure classification and summarization is enabled. Possible values:

    * `image`: A photographic image
    * `chart`: A data chart or graph
    * `diagram`: A schematic or diagram
    * `logo`: A company or brand logo
    * `other`: Any other type of figure
    """

    OTHER = "other"
    CHART = "chart"
    IMAGE = "image"
    DIAGRAM = "diagram"
    LOGO = "logo"
    _UNKNOWN = "__FIGUREDETAILSFIGURETYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "FigureDetailsFigureType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        other: typing.Callable[[], T_Result],
        chart: typing.Callable[[], T_Result],
        image: typing.Callable[[], T_Result],
        diagram: typing.Callable[[], T_Result],
        logo: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is FigureDetailsFigureType.OTHER:
            return other()
        if self is FigureDetailsFigureType.CHART:
            return chart()
        if self is FigureDetailsFigureType.IMAGE:
            return image()
        if self is FigureDetailsFigureType.DIAGRAM:
            return diagram()
        if self is FigureDetailsFigureType.LOGO:
            return logo()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class RunUsage(UncheckedBaseModel):
    """
    Usage credits consumed by a run.

    **Availability:** This field will not be returned for:
    * Runs created before October 7, 2025
    * Customers on legacy billing systems

    For more details on how credits work, see our [Credits Guide](https://docs.extend.ai/2026-02-09/product/general/how-credits-work).
    """

    credits: float = pydantic.Field()
    """
    The number of credits consumed for this run.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .core.api_error import ApiError as core_api_error_ApiError
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .core.http_response import AsyncHttpResponse, HttpResponse
from .core.request_options import RequestOptions
from .core.serialization import convert_and_respect_annotation_metadata
from .core.unchecked_base_model import construct_type
from .errors.bad_request_error import BadRequestError
from .errors.forbidden_error import ForbiddenError
from .errors.internal_server_error import InternalServerError
from .errors.not_found_error import NotFoundError
from .errors.payment_required_error import PaymentRequiredError
from .errors.too_many_requests_error import TooManyRequestsError
from .errors.unauthorized_error import UnauthorizedError
from .errors.unprocessable_entity_error import UnprocessableEntityError
from .requests.classify_config import ClassifyConfigParams
from .requests.classify_request_classifier import ClassifyRequestClassifierParams
from .requests.classify_request_file import ClassifyRequestFileParams
from .requests.edit_config import EditConfigParams
from .requests.edit_request_file import EditRequestFileParams
from .requests.extract_config_json import ExtractConfigJsonParams
from .requests.extract_request_extractor import ExtractRequestExtractorParams
from .requests.extract_request_file import ExtractRequestFileParams
from .requests.parse_config import ParseConfigParams
from .requests.parse_request_file import ParseRequestFileParams
from .requests.split_config import SplitConfigParams
from .requests.split_request_file import SplitRequestFileParams
from .requests.split_request_splitter import SplitRequestSplitterParams
from .types.api_error import ApiError as types_api_error_ApiError
from .types.classify_run import ClassifyRun
from .types.edit_run import EditRun
from .types.extract_run import ExtractRun
from .types.parse_request_response_type import ParseRequestResponseType
from .types.parse_run import ParseRun
from .types.run_metadata import RunMetadata
from .types.split_run import SplitRun

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawExtend:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def parse(
        self,
        *,
        file: ParseRequestFileParams,
        response_type: typing.Optional[ParseRequestResponseType] = None,
        config: typing.Optional[ParseConfigParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ParseRun]:
        """
        Parse a file synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /parse_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Parse endpoint allows you to convert documents into structured, machine-readable formats with fine-grained control over the parsing process. This endpoint is ideal for extracting cleaned document content to be used as context for downstream processing, e.g. RAG pipelines, custom ingestion pipelines, embeddings classification, etc.

        For more details, see the [Parse File guide](https://docs.extend.ai/2026-02-09/product/parsing/parse).

        Parameters
        ----------
        file : ParseRequestFileParams
            The file to be parsed. Files can be provided as a URL or an Extend file ID.

        response_type : typing.Optional[ParseRequestResponseType]
            Controls the format of the response chunks. Defaults to `json` if not specified.
            * `json` - Returns parsed outputs in the response body
            * `url` - Return a presigned URL to the parsed content in the response body

        config : typing.Optional[ParseConfigParams]

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ParseRun]
            Successfully parsed file
        """
        _response = self._client_wrapper.httpx_client.request(
            "parse",
            method="POST",
            params={
                "responseType": response_type,
            },
            json={
                "file": convert_and_respect_annotation_metadata(
                    object_=file, annotation=ParseRequestFileParams, direction="write"
                ),
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=ParseConfigParams, direction="write"
                ),
                "metadata": metadata,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ParseRun,
                    construct_type(
                        type_=ParseRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    def edit(
        self,
        *,
        file: EditRequestFileParams,
        config: typing.Optional[EditConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[EditRun]:
        """
        Edit a file synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /edit_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Edit endpoint allows you to detect and fill form fields in PDF documents.

        For more details, see the [Edit File guide](https://docs.extend.ai/2026-02-09/product/editing/edit).

        Parameters
        ----------
        file : EditRequestFileParams
            The file to be edited. Files can be provided as a URL or an Extend file ID.

        config : typing.Optional[EditConfigParams]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[EditRun]
            Successfully edited file
        """
        _response = self._client_wrapper.httpx_client.request(
            "edit",
            method="POST",
            json={
                "file": convert_and_respect_annotation_metadata(
                    object_=file, annotation=EditRequestFileParams, direction="write"
                ),
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=EditConfigParams, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EditRun,
                    construct_type(
                        type_=EditRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    def extract(
        self,
        *,
        file: ExtractRequestFileParams,
        extractor: typing.Optional[ExtractRequestExtractorParams] = OMIT,
        config: typing.Optional[ExtractConfigJsonParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ExtractRun]:
        """
        Extract structured data from a file synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /extract_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Extract endpoint allows you to extract structured data from files using an existing extractor or an inline configuration.

        For more details, see the [Extract File guide](https://docs.extend.ai/2026-02-09/product/extracting/extract).

        Parameters
        ----------
        file : ExtractRequestFileParams
            The file to be extracted from. Files can be provided as a URL, Extend file ID, or raw text.

        extractor : typing.Optional[ExtractRequestExtractorParams]
            Reference to an existing extractor. One of `extractor` or `config` must be provided.

        config : typing.Optional[ExtractConfigJsonParams]
            Inline extract configuration. One of `extractor` or `config` must be provided.

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ExtractRun]
            Successfully extracted data from file
        """
        _response = self._client_wrapper.httpx_client.request(
            "extract",
            method="POST",
            json={
                "extractor": convert_and_respect_annotation_metadata(
                    object_=extractor, annotation=ExtractRequestExtractorParams, direction="write"
                ),
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=ExtractConfigJsonParams, direction="write"
                ),
                "file": convert_and_respect_annotation_metadata(
                    object_=file, annotation=ExtractRequestFileParams, direction="write"
                ),
                "metadata": metadata,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ExtractRun,
                    construct_type(
                        type_=ExtractRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    def classify(
        self,
        *,
        file: ClassifyRequestFileParams,
        classifier: typing.Optional[ClassifyRequestClassifierParams] = OMIT,
        config: typing.Optional[ClassifyConfigParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ClassifyRun]:
        """
        Classify a document synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /classify_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Classify endpoint allows you to classify documents using an existing classifier or an inline configuration.

        For more details, see the [Classify File guide](https://docs.extend.ai/2026-02-09/product/classifying/classify).

        Parameters
        ----------
        file : ClassifyRequestFileParams
            The file to be classified. Files can be provided as a URL, an Extend file ID, or raw text.

        classifier : typing.Optional[ClassifyRequestClassifierParams]
            Reference to an existing classifier. One of `classifier` or `config` must be provided.

        config : typing.Optional[ClassifyConfigParams]
            Inline classify configuration. One of `classifier` or `config` must be provided.

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ClassifyRun]
            Successfully classified file
        """
        _response = self._client_wrapper.httpx_client.request(
            "classify",
            method="POST",
            json={
                "classifier": convert_and_respect_annotation_metadata(
                    object_=classifier, annotation=ClassifyRequestClassifierParams, direction="write"
                ),
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=ClassifyConfigParams, direction="write"
                ),
                "file": convert_and_respect_annotation_metadata(
                    object_=file, annotation=ClassifyRequestFileParams, direction="write"
                ),
                "metadata": metadata,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ClassifyRun,
                    construct_type(
                        type_=ClassifyRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    def split(
        self,
        *,
        file: SplitRequestFileParams,
        splitter: typing.Optional[SplitRequestSplitterParams] = OMIT,
        config: typing.Optional[SplitConfigParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SplitRun]:
        """
        Split a document synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /split_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Split endpoint allows you to split documents into multiple parts using an existing splitter or an inline configuration.

        For more details, see the [Split File guide](https://docs.extend.ai/2026-02-09/product/splitting/split).

        Parameters
        ----------
        file : SplitRequestFileParams
            The file to be split. Files can be provided as a URL or an Extend file ID.

        splitter : typing.Optional[SplitRequestSplitterParams]
            Reference to an existing splitter. One of `splitter` or `config` must be provided.

        config : typing.Optional[SplitConfigParams]
            Inline splitter configuration. One of `splitter` or `config` must be provided.

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SplitRun]
            Successfully split file
        """
        _response = self._client_wrapper.httpx_client.request(
            "split",
            method="POST",
            json={
                "splitter": convert_and_respect_annotation_metadata(
                    object_=splitter, annotation=SplitRequestSplitterParams, direction="write"
                ),
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=SplitConfigParams, direction="write"
                ),
                "file": convert_and_respect_annotation_metadata(
                    object_=file, annotation=SplitRequestFileParams, direction="write"
                ),
                "metadata": metadata,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SplitRun,
                    construct_type(
                        type_=SplitRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )


class AsyncRawExtend:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def parse(
        self,
        *,
        file: ParseRequestFileParams,
        response_type: typing.Optional[ParseRequestResponseType] = None,
        config: typing.Optional[ParseConfigParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ParseRun]:
        """
        Parse a file synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /parse_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Parse endpoint allows you to convert documents into structured, machine-readable formats with fine-grained control over the parsing process. This endpoint is ideal for extracting cleaned document content to be used as context for downstream processing, e.g. RAG pipelines, custom ingestion pipelines, embeddings classification, etc.

        For more details, see the [Parse File guide](https://docs.extend.ai/2026-02-09/product/parsing/parse).

        Parameters
        ----------
        file : ParseRequestFileParams
            The file to be parsed. Files can be provided as a URL or an Extend file ID.

        response_type : typing.Optional[ParseRequestResponseType]
            Controls the format of the response chunks. Defaults to `json` if not specified.
            * `json` - Returns parsed outputs in the response body
            * `url` - Return a presigned URL to the parsed content in the response body

        config : typing.Optional[ParseConfigParams]

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ParseRun]
            Successfully parsed file
        """
        _response = await self._client_wrapper.httpx_client.request(
            "parse",
            method="POST",
            params={
                "responseType": response_type,
            },
            json={
                "file": convert_and_respect_annotation_metadata(
                    object_=file, annotation=ParseRequestFileParams, direction="write"
                ),
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=ParseConfigParams, direction="write"
                ),
                "metadata": metadata,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ParseRun,
                    construct_type(
                        type_=ParseRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    async def edit(
        self,
        *,
        file: EditRequestFileParams,
        config: typing.Optional[EditConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[EditRun]:
        """
        Edit a file synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /edit_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Edit endpoint allows you to detect and fill form fields in PDF documents.

        For more details, see the [Edit File guide](https://docs.extend.ai/2026-02-09/product/editing/edit).

        Parameters
        ----------
        file : EditRequestFileParams
            The file to be edited. Files can be provided as a URL or an Extend file ID.

        config : typing.Optional[EditConfigParams]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[EditRun]
            Successfully edited file
        """
        _response = await self._client_wrapper.httpx_client.request(
            "edit",
            method="POST",
            json={
                "file": convert_and_respect_annotation_metadata(
                    object_=file, annotation=EditRequestFileParams, direction="write"
                ),
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=EditConfigParams, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EditRun,
                    construct_type(
                        type_=EditRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    async def extract(
        self,
        *,
        file: ExtractRequestFileParams,
        extractor: typing.Optional[ExtractRequestExtractorParams] = OMIT,
        config: typing.Optional[ExtractConfigJsonParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ExtractRun]:
        """
        Extract structured data from a file synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /extract_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Extract endpoint allows you to extract structured data from files using an existing extractor or an inline configuration.

        For more details, see the [Extract File guide](https://docs.extend.ai/2026-02-09/product/extracting/extract).

        Parameters
        ----------
        file : ExtractRequestFileParams
            The file to be extracted from. Files can be provided as a URL, Extend file ID, or raw text.

        extractor : typing.Optional[ExtractRequestExtractorParams]
            Reference to an existing extractor. One of `extractor` or `config` must be provided.

        config : typing.Optional[ExtractConfigJsonParams]
            Inline extract configuration. One of `extractor` or `config` must be provided.

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ExtractRun]
            Successfully extracted data from file
        """
        _response = await self._client_wrapper.httpx_client.request(
            "extract",
            method="POST",
            json={
                "extractor": convert_and_respect_annotation_metadata(
                    object_=extractor, annotation=ExtractRequestExtractorParams, direction="write"
                ),
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=ExtractConfigJsonParams, direction="write"
                ),
                "file": convert_and_respect_annotation_metadata(
                    object_=file, annotation=ExtractRequestFileParams, direction="write"
                ),
                "metadata": metadata,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ExtractRun,
                    construct_type(
                        type_=ExtractRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    async def classify(
        self,
        *,
        file: ClassifyRequestFileParams,
        classifier: typing.Optional[ClassifyRequestClassifierParams] = OMIT,
        config: typing.Optional[ClassifyConfigParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ClassifyRun]:
        """
        Classify a document synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /classify_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Classify endpoint allows you to classify documents using an existing classifier or an inline configuration.

        For more details, see the [Classify File guide](https://docs.extend.ai/2026-02-09/product/classifying/classify).

        Parameters
        ----------
        file : ClassifyRequestFileParams
            The file to be classified. Files can be provided as a URL, an Extend file ID, or raw text.

        classifier : typing.Optional[ClassifyRequestClassifierParams]
            Reference to an existing classifier. One of `classifier` or `config` must be provided.

        config : typing.Optional[ClassifyConfigParams]
            Inline classify configuration. One of `classifier` or `config` must be provided.

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ClassifyRun]
            Successfully classified file
        """
        _response = await self._client_wrapper.httpx_client.request(
            "classify",
            method="POST",
            json={
                "classifier": convert_and_respect_annotation_metadata(
                    object_=classifier, annotation=ClassifyRequestClassifierParams, direction="write"
                ),
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=ClassifyConfigParams, direction="write"
                ),
                "file": convert_and_respect_annotation_metadata(
                    object_=file, annotation=ClassifyRequestFileParams, direction="write"
                ),
                "metadata": metadata,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ClassifyRun,
                    construct_type(
                        type_=ClassifyRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    async def split(
        self,
        *,
        file: SplitRequestFileParams,
        splitter: typing.Optional[SplitRequestSplitterParams] = OMIT,
        config: typing.Optional[SplitConfigParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SplitRun]:
        """
        Split a document synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /split_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Split endpoint allows you to split documents into multiple parts using an existing splitter or an inline configuration.

        For more details, see the [Split File guide](https://docs.extend.ai/2026-02-09/product/splitting/split).

        Parameters
        ----------
        file : SplitRequestFileParams
            The file to be split. Files can be provided as a URL or an Extend file ID.

        splitter : typing.Optional[SplitRequestSplitterParams]
            Reference to an existing splitter. One of `splitter` or `config` must be provided.

        config : typing.Optional[SplitConfigParams]
            Inline splitter configuration. One of `splitter` or `config` must be provided.

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SplitRun]
            Successfully split file
        """
        _response = await self._client_wrapper.httpx_client.request(
            "split",
            method="POST",
            json={
                "splitter": convert_and_respect_annotation_metadata(
                    object_=splitter, annotation=SplitRequestSplitterParams, direction="write"
                ),
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=SplitConfigParams, direction="write"
                ),
                "file": convert_and_respect_annotation_metadata(
                    object_=file, annotation=SplitRequestFileParams, direction="write"
                ),
                "metadata": metadata,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SplitRun,
                    construct_type(
                        type_=SplitRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError as core_api_error_ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..core.unchecked_base_model import construct_type
from ..errors.bad_request_error import BadRequestError
from ..errors.forbidden_error import ForbiddenError
from ..errors.internal_server_error import InternalServerError
from ..errors.not_found_error import NotFoundError
from ..errors.payment_required_error import PaymentRequiredError
from ..errors.too_many_requests_error import TooManyRequestsError
from ..errors.unauthorized_error import UnauthorizedError
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..requests.edit_config import EditConfigParams
from ..types.api_error import ApiError as types_api_error_ApiError
from ..types.edit_run import EditRun
from .requests.edit_runs_create_request_file import EditRunsCreateRequestFileParams
from .types.edit_runs_delete_response import EditRunsDeleteResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawEditRunsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create(
        self,
        *,
        file: EditRunsCreateRequestFileParams,
        config: typing.Optional[EditConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[EditRun]:
        """
        Edit and manipulate PDF documents by detecting and filling form fields.

        The Edit Runs endpoint allows you to convert and edit documents and get an edit run ID that can be used to check status and retrieve results with the [Get Edit Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/edit/get-edit-run) endpoint.

        For more details, see the [Edit File guide](https://docs.extend.ai/2026-02-09/product/editing/edit).

        Parameters
        ----------
        file : EditRunsCreateRequestFileParams
            The file to be edited. Files can be provided as a URL or an Extend file ID.

        config : typing.Optional[EditConfigParams]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[EditRun]
            Successfully initiated edit run
        """
        _response = self._client_wrapper.httpx_client.request(
            "edit_runs",
            method="POST",
            json={
                "file": convert_and_respect_annotation_metadata(
                    object_=file, annotation=EditRunsCreateRequestFileParams, direction="write"
                ),
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=EditConfigParams, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EditRun,
                    construct_type(
                        type_=EditRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    def retrieve(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[EditRun]:
        """
        Retrieve the status and results of an edit run.

        Use this endpoint to get results for an edit run that has already completed, or to check on the status of an edit run initiated via the [Create Edit Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/edit/create-edit-run) endpoint.

        Parameters
        ----------
        id : str
            The unique identifier for the edit run.

            Example: `"edr_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[EditRun]
            Successfully retrieved edit run
        """
        _response = self._client_wrapper.httpx_client.request(
            f"edit_runs/{jsonable_encoder(id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EditRun,
                    construct_type(
                        type_=EditRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    def delete(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[EditRunsDeleteResponse]:
        """
        Delete an edit run and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than relying on automated data retention policies, or to make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the edit run to delete.

            Example: `"edr_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[EditRunsDeleteResponse]
            Successfully deleted edit run
        """
        _response = self._client_wrapper.httpx_client.request(
            f"edit_runs/{jsonable_encoder(id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EditRunsDeleteResponse,
                    construct_type(
                        type_=EditRunsDeleteResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )


class AsyncRawEditRunsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create(
        self,
        *,
        file: EditRunsCreateRequestFileParams,
        config: typing.Optional[EditConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[EditRun]:
        """
        Edit and manipulate PDF documents by detecting and filling form fields.

        The Edit Runs endpoint allows you to convert and edit documents and get an edit run ID that can be used to check status and retrieve results with the [Get Edit Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/edit/get-edit-run) endpoint.

        For more details, see the [Edit File guide](https://docs.extend.ai/2026-02-09/product/editing/edit).

        Parameters
        ----------
        file : EditRunsCreateRequestFileParams
            The file to be edited. Files can be provided as a URL or an Extend file ID.

        config : typing.Optional[EditConfigParams]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[EditRun]
            Successfully initiated edit run
        """
        _response = await self._client_wrapper.httpx_client.request(
            "edit_runs",
            method="POST",
            json={
                "file": convert_and_respect_annotation_metadata(
                    object_=file, annotation=EditRunsCreateRequestFileParams, direction="write"
                ),
                "config": convert_and_respect_annotation_metadata(
                    object_=config, annotation=EditConfigParams, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EditRun,
                    construct_type(
                        type_=EditRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    async def retrieve(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[EditRun]:
        """
        Retrieve the status and results of an edit run.

        Use this endpoint to get results for an edit run that has already completed, or to check on the status of an edit run initiated via the [Create Edit Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/edit/create-edit-run) endpoint.

        Parameters
        ----------
        id : str
            The unique identifier for the edit run.

            Example: `"edr_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[EditRun]
            Successfully retrieved edit run
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"edit_runs/{jsonable_encoder(id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EditRun,
                    construct_type(
                        type_=EditRun,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    async def delete(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[EditRunsDeleteResponse]:
        """
        Delete an edit run and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than relying on automated data retention policies, or to make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the edit run to delete.

            Example: `"edr_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[EditRunsDeleteResponse]
            Successfully deleted edit run
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"edit_runs/{jsonable_encoder(id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    EditRunsDeleteResponse,
                    construct_type(
                        type_=EditRunsDeleteResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.processor_version_string import ProcessorVersionString
from .split_config import SplitConfigParams


class SplitRequestSplitterParams(typing_extensions.TypedDict):
    """
    Reference to an existing splitter. One of `splitter` or `config` must be provided.
    """

    id: str
    """
    The ID of the splitter to use.
    """

    version: typing_extensions.NotRequired[ProcessorVersionString]
    override_config: typing_extensions.NotRequired[
        typing_extensions.Annotated[SplitConfigParams, FieldMetadata(alias="overrideConfig")]
    ]
    """
    Optional configuration override. If provided, this configuration will override the splitter's saved configuration.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..requests.extract_config_json import ExtractConfigJsonParams
from ..types.extractor_version import ExtractorVersion
from ..types.max_page_size import MaxPageSize
from ..types.next_page_token import NextPageToken
from ..types.release_type import ReleaseType
from ..types.sort_dir import SortDir
from ..types.version_description import VersionDescription
from .raw_client import AsyncRawExtractorVersionsClient, RawExtractorVersionsClient
from .types.extractor_versions_list_response import ExtractorVersionsListResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ExtractorVersionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawExtractorVersionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawExtractorVersionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawExtractorVersionsClient
        """
        return self._raw_client

    def list(
        self,
        extractor_id: str,
        *,
        sort_dir: typing.Optional[SortDir] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ExtractorVersionsListResponse:
        """
        This endpoint allows you to fetch all versions of a given extractor, including the current `draft` version.

        Versions are returned in descending order of creation (newest first) with the `draft` version first. The `draft` version is the latest unpublished version of the extractor, which can be published to create a new version. It might not have any changes from the last published version.

        Parameters
        ----------
        extractor_id : str
            The ID of the extractor.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        sort_dir : typing.Optional[SortDir]

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExtractorVersionsListResponse
            Successfully retrieved extractor versions

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.extractor_versions.list(
            extractor_id="extractor_id_here",
            next_page_token="xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=",
        )
        """
        _response = self._raw_client.list(
            extractor_id,
            sort_dir=sort_dir,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            request_options=request_options,
        )
        return _response.data

    def create(
        self,
        extractor_id: str,
        *,
        release_type: ReleaseType,
        description: typing.Optional[VersionDescription] = OMIT,
        config: typing.Optional[ExtractConfigJsonParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ExtractorVersion:
        """
        This endpoint allows you to publish a new version of an existing extractor. Publishing a new version creates a snapshot of the extractor's current configuration and makes it available for use in workflows.

        Publishing a new version does not automatically update existing workflows using this extractor. You may need to manually update workflows to use the new version if desired.

        Parameters
        ----------
        extractor_id : str
            The ID of the extractor.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        release_type : ReleaseType

        description : typing.Optional[VersionDescription]

        config : typing.Optional[ExtractConfigJsonParams]
            The configuration for this version of the extractor.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExtractorVersion
            Successfully published extractor version

        Examples
        --------
        from extend_ai import Extend, ReleaseType

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.extractor_versions.create(
            extractor_id="extractor_id_here",
            release_type=ReleaseType.MAJOR,
        )
        """
        _response = self._raw_client.create(
            extractor_id,
            release_type=release_type,
            description=description,
            config=config,
            request_options=request_options,
        )
        return _response.data

    def retrieve(
        self, extractor_id: str, version_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ExtractorVersion:
        """
        Retrieve a specific version of an extractor in Extend

        Parameters
        ----------
        extractor_id : str
            The ID of the extractor.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        version_id : str
            The ID of the specific extractor version.

            Example: `"extv_QYk6jgHA_8CsO8rVWhyNC"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExtractorVersion
            Successfully retrieved extractor version

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.extractor_versions.retrieve(
            extractor_id="extractor_id_here",
            version_id="extractor_version_id_here",
        )
        """
        _response = self._raw_client.retrieve(extractor_id, version_id, request_options=request_options)
        return _response.data


class AsyncExtractorVersionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawExtractorVersionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawExtractorVersionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawExtractorVersionsClient
        """
        return self._raw_client

    async def list(
        self,
        extractor_id: str,
        *,
        sort_dir: typing.Optional[SortDir] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ExtractorVersionsListResponse:
        """
        This endpoint allows you to fetch all versions of a given extractor, including the current `draft` version.

        Versions are returned in descending order of creation (newest first) with the `draft` version first. The `draft` version is the latest unpublished version of the extractor, which can be published to create a new version. It might not have any changes from the last published version.

        Parameters
        ----------
        extractor_id : str
            The ID of the extractor.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        sort_dir : typing.Optional[SortDir]

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExtractorVersionsListResponse
            Successfully retrieved extractor versions

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.extractor_versions.list(
                extractor_id="extractor_id_here",
                next_page_token="xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            extractor_id,
            sort_dir=sort_dir,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            request_options=request_options,
        )
        return _response.data

    async def create(
        self,
        extractor_id: str,
        *,
        release_type: ReleaseType,
        description: typing.Optional[VersionDescription] = OMIT,
        config: typing.Optional[ExtractConfigJsonParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ExtractorVersion:
        """
        This endpoint allows you to publish a new version of an existing extractor. Publishing a new version creates a snapshot of the extractor's current configuration and makes it available for use in workflows.

        Publishing a new version does not automatically update existing workflows using this extractor. You may need to manually update workflows to use the new version if desired.

        Parameters
        ----------
        extractor_id : str
            The ID of the extractor.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        release_type : ReleaseType

        description : typing.Optional[VersionDescription]

        config : typing.Optional[ExtractConfigJsonParams]
            The configuration for this version of the extractor.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExtractorVersion
            Successfully published extractor version

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend, ReleaseType

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.extractor_versions.create(
                extractor_id="extractor_id_here",
                release_type=ReleaseType.MAJOR,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            extractor_id,
            release_type=release_type,
            description=description,
            config=config,
            request_options=request_options,
        )
        return _response.data

    async def retrieve(
        self, extractor_id: str, version_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ExtractorVersion:
        """
        Retrieve a specific version of an extractor in Extend

        Parameters
        ----------
        extractor_id : str
            The ID of the extractor.

            Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`

        version_id : str
            The ID of the specific extractor version.

            Example: `"extv_QYk6jgHA_8CsO8rVWhyNC"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExtractorVersion
            Successfully retrieved extractor version

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.extractor_versions.retrieve(
                extractor_id="extractor_id_here",
                version_id="extractor_version_id_here",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.retrieve(extractor_id, version_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .extract_run import ExtractRunParams


class ConditionalExtractResultParams(typing_extensions.TypedDict):
    """
    The result of a conditional extract step, which routes to different extractors based on rules.
    """

    extract_run: typing_extensions.Annotated[ExtractRunParams, FieldMetadata(alias="extractRun")]
    """
    The extract run that was executed based on the matched rule.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.legacy_extraction_field_result_type import LegacyExtractionFieldResultType
from .enum_option import EnumOptionParams
from .extraction_field_result_reference import ExtractionFieldResultReferenceParams
from .insight import InsightParams
from .legacy_extraction_field import LegacyExtractionFieldParams


class LegacyExtractionFieldResultParams(typing_extensions.TypedDict):
    id: str
    """
    The unique identifier for this field
    """

    type: LegacyExtractionFieldResultType
    """
    The type of the extracted field
    """

    value: typing.Any
    confidence: typing_extensions.NotRequired[float]
    """
    A value between 0 and 1 indicating confidence in the extraction
    """

    schema: typing_extensions.NotRequired[typing.Sequence[LegacyExtractionFieldParams]]
    """
    The field schema of nested fields
    """

    insights: typing_extensions.NotRequired[typing.Sequence[InsightParams]]
    """
    Reasoning and other insights from the model
    """

    references: typing.Sequence[ExtractionFieldResultReferenceParams]
    """
    References for the extracted field
    """

    enum: typing_extensions.NotRequired[typing.Sequence[EnumOptionParams]]
    """
    The enum options for enum fields, only set when type=enum
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.legacy_provided_extraction_field_result_type import LegacyProvidedExtractionFieldResultType


class LegacyProvidedExtractionFieldResultParams(typing_extensions.TypedDict):
    id: str
    """
    The unique identifier for this field
    """

    value: typing.Any
    type: typing_extensions.NotRequired[LegacyProvidedExtractionFieldResultType]
    """
    The type of the extraction field result
    """

    confidence: typing_extensions.NotRequired[float]
    """
    A value between 0 and 1 indicating confidence in the extraction. Will be set to 1 if not provided.
    """

    page: typing_extensions.NotRequired[typing.Optional[float]]
    """
    The page number where this field was extracted from
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class BlockMetadataPage(UncheckedBaseModel):
    """
    Information about the page this block appears on.
    """

    number: int = pydantic.Field()
    """
    The page number where this block appears.
    """

    width: typing.Optional[float] = pydantic.Field(default=None)
    """
    The width of the page in points.
    """

    height: typing.Optional[float] = pydantic.Field(default=None)
    """
    The height of the page in points.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .edit_run_output_edited_file import EditRunOutputEditedFile


class EditRunOutput(UncheckedBaseModel):
    """
    The output of the edit run.

    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    edited_file: typing_extensions.Annotated[EditRunOutputEditedFile, FieldMetadata(alias="editedFile")] = (
        pydantic.Field(alias="editedFile")
    )
    """
    Information about the edited output file.
    """

    filled_values: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Any]], FieldMetadata(alias="filledValues")
    ] = pydantic.Field(alias="filledValues", default=None)
    """
    The field values that were filled into the document. Keys correspond to the property names in the schema. Will not be present if no values were filled.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class EnumParams(typing_extensions.TypedDict):
    value: str
    """
    The value of the enum option.
    """

    description: str
    """
    Description of what this enum value represents.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.json_object import JsonObject
from ..types.legacy_extraction_config_base_processor import LegacyExtractionConfigBaseProcessor
from .legacy_extraction_advanced_options import LegacyExtractionAdvancedOptionsParams
from .legacy_extraction_field import LegacyExtractionFieldParams
from .parse_config import ParseConfigParams


class LegacyExtractionConfigParams(typing_extensions.TypedDict):
    base_processor: typing_extensions.NotRequired[
        typing_extensions.Annotated[LegacyExtractionConfigBaseProcessor, FieldMetadata(alias="baseProcessor")]
    ]
    """
    The base processor to use. For extractors, this must be either `"extraction_performance"` or `"extraction_light"`. See [Extraction Changelog](/changelog/extraction/extraction-performance) for more details.
    """

    base_version: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="baseVersion")]]
    """
    The version of the `"extraction_performance"` or `"extraction_light"` processor to use. If this is provided, the `baseProcessor` must also be provided. See [Extraction Changelog](/changelog/extraction/extraction-performance) for more details.
    """

    extraction_rules: typing_extensions.NotRequired[
        typing_extensions.Annotated[str, FieldMetadata(alias="extractionRules")]
    ]
    """
    Custom rules to guide the extraction process in natural language.
    """

    schema: typing_extensions.NotRequired[JsonObject]
    """
    JSON Schema definition of the data to extract. Either `fields` or `schema` must be provided.
    
    See the [JSON Schema guide](/product/extraction/schema/json-schema) for details and examples of schema configuration.
    """

    fields: typing_extensions.NotRequired[typing.Sequence[LegacyExtractionFieldParams]]
    """
    Array of fields to extract from the document. Either `fields` or `schema` must be provided.
    
    We recommend using `schema` for new implementations.
    """

    advanced_options: typing_extensions.NotRequired[
        typing_extensions.Annotated[LegacyExtractionAdvancedOptionsParams, FieldMetadata(alias="advancedOptions")]
    ]
    """
    Advanced configuration options.
    """

    parser: typing_extensions.NotRequired[ParseConfigParams]
    """
    Configuration options for the parsing process.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .classify_config import ClassifyConfig
from .processor_version_string import ProcessorVersionString


class ClassifyRequestClassifier(UncheckedBaseModel):
    """
    Reference to an existing classifier. One of `classifier` or `config` must be provided.
    """

    id: str = pydantic.Field()
    """
    The ID of the classifier to use.
    """

    version: typing.Optional[ProcessorVersionString] = None
    override_config: typing_extensions.Annotated[
        typing.Optional[ClassifyConfig], FieldMetadata(alias="overrideConfig")
    ] = pydantic.Field(alias="overrideConfig", default=None)
    """
    Optional configuration override. If provided, this configuration will override the classifier's saved configuration.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .file_summary import FileSummary
from .parse_config import ParseConfig
from .parse_run_metrics import ParseRunMetrics
from .parse_run_output import ParseRunOutput
from .parse_run_status_enum import ParseRunStatusEnum
from .run_usage import RunUsage


class ParseRun(UncheckedBaseModel):
    """
    Parse run object.
    """

    object: typing.Literal["parse_run"] = pydantic.Field(default="parse_run")
    """
    The type of object. Will always be `"parse_run"`.
    """

    id: str = pydantic.Field()
    """
    A unique identifier for the parse run.
    
    Example: `"pr_xK9mLPqRtN3vS8wF5hB2cQ"`
    """

    file: FileSummary = pydantic.Field()
    """
    The file that was parsed. This file can be used as a parameter for other Extend endpoints, such as `POST /workflow_runs`.
    """

    status: ParseRunStatusEnum = pydantic.Field()
    """
    The status of the parse run:
    * `"PROCESSING"` - The file is still being processed
    * `"PROCESSED"` - The file was successfully processed
    * `"FAILED"` - The processing failed (see `failureReason` for details)
    """

    failure_reason: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureReason")] = (
        pydantic.Field(alias="failureReason", default=None)
    )
    """
    The reason for failure.
    
    **Availability:** Present when `status` is `"FAILED"`.
    
    Possible values include:
    * `UNABLE_TO_DOWNLOAD_FILE` - The file could not be downloaded from the provided URL
    * `FILE_TYPE_NOT_SUPPORTED` - The file type is not supported for parsing
    * `FILE_SIZE_TOO_LARGE` - The file exceeds the maximum allowed size
    * `CORRUPT_FILE` - The file appears to be corrupted or malformed
    * `OCR_ERROR` - An error occurred during optical character recognition
    * `PASSWORD_PROTECTED_FILE` - The file is password protected and cannot be processed
    * `FAILED_TO_CONVERT_TO_PDF` - The file could not be converted to PDF for processing
    * `FAILED_TO_CONVERT_TO_JPEG` - The file could not be converted to JPEG for processing
    * `FAILED_TO_GENERATE_TARGET_FORMAT` - The output could not be generated in the requested format
    * `CHUNKING_ERROR` - An error occurred while chunking the document
    * `INTERNAL_ERROR` - An unexpected internal error occurred
    * `INVALID_CONFIG_OPTIONS` - The provided configuration options are invalid
    * `OUT_OF_CREDITS` - Insufficient credits to process the file
    
    **Note:** Additional failure reasons may be added in the future. Your integration should handle unknown values gracefully.
    """

    failure_message: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureMessage")] = (
        pydantic.Field(alias="failureMessage", default=None)
    )
    """
    A human-readable description of the failure.
    
    **Availability:** Present when `status` is `"FAILED"`.
    """

    output: typing.Optional[ParseRunOutput] = pydantic.Field(default=None)
    """
    The parse run output.
    
    **Availability:** Present when `status` is `"PROCESSED"` and the request was made without the `responseType=url` query parameter. Contains the parsed chunks.
    """

    output_url: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="outputUrl")] = pydantic.Field(
        alias="outputUrl", default=None
    )
    """
    A presigned URL to download the parse run output as a JSON file. The object shape is the same as the `output` field. Expires after 15 minutes.
    
    **Availability:** Present when `status` is `"PROCESSED"` and the request was made with `responseType=url` query parameter.
    """

    metrics: typing.Optional[ParseRunMetrics] = pydantic.Field(default=None)
    """
    Metrics about the parsing process.
    
    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    config: ParseConfig = pydantic.Field()
    """
    The configuration used for the parsing process, including any default values that were applied.
    """

    usage: typing.Optional[RunUsage] = pydantic.Field(default=None)
    """
    Usage credits consumed by this run.
    
    **Availability:** Present when `status` is `"PROCESSED"`, the run was created after October 7, 2025, and the customer is on the current billing system.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(ParseRun)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .array_strategy import ArrayStrategy
from .excel_sheet_range import ExcelSheetRange
from .legacy_extract_chunking_options import LegacyExtractChunkingOptions
from .legacy_extraction_advanced_options_array_citation_strategy import (
    LegacyExtractionAdvancedOptionsArrayCitationStrategy,
)
from .legacy_extraction_advanced_options_excel_sheet_selection_strategy import (
    LegacyExtractionAdvancedOptionsExcelSheetSelectionStrategy,
)
from .legacy_extraction_advanced_options_review_agent import LegacyExtractionAdvancedOptionsReviewAgent
from .page_ranges import PageRanges


class LegacyExtractionAdvancedOptions(UncheckedBaseModel):
    document_kind: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="documentKind")] = (
        pydantic.Field(alias="documentKind", default=None)
    )
    """
    DEPRECATED - use extractionRules for all system prompts.
    """

    key_definitions: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="keyDefinitions")] = (
        pydantic.Field(alias="keyDefinitions", default=None)
    )
    """
    DEPRECATED - use extractionRules for all system prompts.
    """

    model_reasoning_insights_enabled: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="modelReasoningInsightsEnabled")
    ] = pydantic.Field(alias="modelReasoningInsightsEnabled", default=None)
    """
    Whether to enable model reasoning insights.
    """

    advanced_multimodal_enabled: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="advancedMultimodalEnabled")
    ] = pydantic.Field(alias="advancedMultimodalEnabled", default=None)
    """
    Whether to enable advanced multimodal features.
    """

    citations_enabled: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="citationsEnabled")] = (
        pydantic.Field(alias="citationsEnabled", default=None)
    )
    """
    Whether to enable citations in the output.
    """

    array_citation_strategy: typing_extensions.Annotated[
        typing.Optional[LegacyExtractionAdvancedOptionsArrayCitationStrategy],
        FieldMetadata(alias="arrayCitationStrategy"),
    ] = pydantic.Field(alias="arrayCitationStrategy", default=None)
    """
    Granularity for array citations. This requires citationsEnabled=true and a base processor version that supports property-level array citations (extraction_performance ≥ 4.4.0).
    """

    advanced_figure_parsing_enabled: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="advancedFigureParsingEnabled")
    ] = pydantic.Field(alias="advancedFigureParsingEnabled", default=None)
    """
    Whether to enable advanced figure parsing.
    """

    review_agent: typing_extensions.Annotated[
        typing.Optional[LegacyExtractionAdvancedOptionsReviewAgent], FieldMetadata(alias="reviewAgent")
    ] = pydantic.Field(alias="reviewAgent", default=None)
    """
    Configuration for the review agent that analyzes extraction results.
    When enabled, each field in the output metadata will include a `reviewAgentScore` (1-5)
    and may include additional `insights` of type `issue` or `review_summary` to help identify
    fields that may need manual review.
    
    To learn more, view the [Review Agent Documentation](https://docs.extend.ai/product/extraction/review-agent)
    """

    array_strategy: typing_extensions.Annotated[
        typing.Optional[ArrayStrategy], FieldMetadata(alias="arrayStrategy")
    ] = pydantic.Field(alias="arrayStrategy", default=None)
    """
    Strategy for handling large arrays in documents.
    """

    chunking_options: typing_extensions.Annotated[
        typing.Optional[LegacyExtractChunkingOptions], FieldMetadata(alias="chunkingOptions")
    ] = pydantic.Field(alias="chunkingOptions", default=None)
    excel_sheet_ranges: typing_extensions.Annotated[
        typing.Optional[typing.List[ExcelSheetRange]], FieldMetadata(alias="excelSheetRanges")
    ] = pydantic.Field(alias="excelSheetRanges", default=None)
    """
    Ranges of sheet indices to extract from Excel documents.
    """

    excel_sheet_selection_strategy: typing_extensions.Annotated[
        typing.Optional[LegacyExtractionAdvancedOptionsExcelSheetSelectionStrategy],
        FieldMetadata(alias="excelSheetSelectionStrategy"),
    ] = pydantic.Field(alias="excelSheetSelectionStrategy", default=None)
    """
    Strategy for selecting sheets from Excel documents.
    """

    fixed_page_limit: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="fixedPageLimit")] = (
        pydantic.Field(alias="fixedPageLimit", default=None)
    )
    """
    DEPRECATED - See [Page Ranges](/product/page-ranges).
    """

    page_ranges: typing_extensions.Annotated[typing.Optional[PageRanges], FieldMetadata(alias="pageRanges")] = (
        pydantic.Field(alias="pageRanges", default=None)
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class EditJsonExtendEditFieldType(enum.StrEnum):
    """
    The PDF field type to edit. Allowed values depend on the schema type:
    * `["string", "null"]` → `text`, `signature`
    * `["number", "null"]` → `text`
    * `["integer", "null"]` → `text`
    * `["boolean", "null"]` → `checkbox`, `radio`
    * `"array"` → `text`, `table`
    * `"object"` → `signature`
    * enum fields (no type) → `radio`, `optionList`, `dropdown`
    """

    TEXT = "text"
    CHECKBOX = "checkbox"
    RADIO = "radio"
    DROPDOWN = "dropdown"
    OPTION_LIST = "optionList"
    SIGNATURE = "signature"
    TABLE = "table"
    UNKNOWN = "unknown"
    _UNKNOWN = "__EDITJSONEXTENDEDITFIELDTYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "EditJsonExtendEditFieldType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        text: typing.Callable[[], T_Result],
        checkbox: typing.Callable[[], T_Result],
        radio: typing.Callable[[], T_Result],
        dropdown: typing.Callable[[], T_Result],
        option_list: typing.Callable[[], T_Result],
        signature: typing.Callable[[], T_Result],
        table: typing.Callable[[], T_Result],
        unknown: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is EditJsonExtendEditFieldType.TEXT:
            return text()
        if self is EditJsonExtendEditFieldType.CHECKBOX:
            return checkbox()
        if self is EditJsonExtendEditFieldType.RADIO:
            return radio()
        if self is EditJsonExtendEditFieldType.DROPDOWN:
            return dropdown()
        if self is EditJsonExtendEditFieldType.OPTION_LIST:
            return option_list()
        if self is EditJsonExtendEditFieldType.SIGNATURE:
            return signature()
        if self is EditJsonExtendEditFieldType.TABLE:
            return table()
        if self is EditJsonExtendEditFieldType.UNKNOWN:
            return unknown()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

from .legacy_extraction_field_result import LegacyExtractionFieldResult

LegacyFieldsArrayOutput = typing.Dict[str, LegacyExtractionFieldResult]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .parse_config_block_options_text_agentic import ParseConfigBlockOptionsTextAgentic


class ParseConfigBlockOptionsText(UncheckedBaseModel):
    """
    Options for text blocks.
    """

    signature_detection_enabled: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="signatureDetectionEnabled")
    ] = pydantic.Field(alias="signatureDetectionEnabled", default=None)
    """
    Whether an additional vision model will be utilized for advanced signature detection. Recommended for most use cases, but should be disabled if signature detection is not necessary and latency is a concern.
    """

    agentic: typing.Optional[ParseConfigBlockOptionsTextAgentic] = pydantic.Field(default=None)
    """
    Options for agentic text processing using VLM-based review and correction.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.json_object import JsonObject
from ..types.legacy_classification_config_base_processor import LegacyClassificationConfigBaseProcessor
from ..types.legacy_extraction_config_base_processor import LegacyExtractionConfigBaseProcessor
from ..types.legacy_splitter_config_base_processor import LegacySplitterConfigBaseProcessor
from .legacy_classification import LegacyClassificationParams
from .legacy_classification_advanced_options import LegacyClassificationAdvancedOptionsParams
from .legacy_extraction_advanced_options import LegacyExtractionAdvancedOptionsParams
from .legacy_extraction_field import LegacyExtractionFieldParams
from .legacy_splitter_advanced_options import LegacySplitterAdvancedOptionsParams
from .parse_config import ParseConfigParams


class LegacyProcessorVersionConfig_ClassifyParams(typing_extensions.TypedDict):
    type: typing.Literal["CLASSIFY"]
    base_processor: typing_extensions.NotRequired[
        typing_extensions.Annotated[LegacyClassificationConfigBaseProcessor, FieldMetadata(alias="baseProcessor")]
    ]
    base_version: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="baseVersion")]]
    classifications: typing.Sequence[LegacyClassificationParams]
    classification_rules: typing_extensions.NotRequired[
        typing_extensions.Annotated[str, FieldMetadata(alias="classificationRules")]
    ]
    advanced_options: typing_extensions.NotRequired[
        typing_extensions.Annotated[LegacyClassificationAdvancedOptionsParams, FieldMetadata(alias="advancedOptions")]
    ]
    parser: typing_extensions.NotRequired[ParseConfigParams]


class LegacyProcessorVersionConfig_ExtractParams(typing_extensions.TypedDict):
    type: typing.Literal["EXTRACT"]
    base_processor: typing_extensions.NotRequired[
        typing_extensions.Annotated[LegacyExtractionConfigBaseProcessor, FieldMetadata(alias="baseProcessor")]
    ]
    base_version: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="baseVersion")]]
    extraction_rules: typing_extensions.NotRequired[
        typing_extensions.Annotated[str, FieldMetadata(alias="extractionRules")]
    ]
    schema: typing_extensions.NotRequired[JsonObject]
    fields: typing_extensions.NotRequired[typing.Sequence[LegacyExtractionFieldParams]]
    advanced_options: typing_extensions.NotRequired[
        typing_extensions.Annotated[LegacyExtractionAdvancedOptionsParams, FieldMetadata(alias="advancedOptions")]
    ]
    parser: typing_extensions.NotRequired[ParseConfigParams]


class LegacyProcessorVersionConfig_SplitterParams(typing_extensions.TypedDict):
    type: typing.Literal["SPLITTER"]
    base_processor: typing_extensions.NotRequired[
        typing_extensions.Annotated[LegacySplitterConfigBaseProcessor, FieldMetadata(alias="baseProcessor")]
    ]
    base_version: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="baseVersion")]]
    split_classifications: typing_extensions.Annotated[
        typing.Sequence[LegacyClassificationParams], FieldMetadata(alias="splitClassifications")
    ]
    split_rules: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="splitRules")]]
    advanced_options: typing_extensions.NotRequired[
        typing_extensions.Annotated[LegacySplitterAdvancedOptionsParams, FieldMetadata(alias="advancedOptions")]
    ]
    parser: typing_extensions.NotRequired[ParseConfigParams]


LegacyProcessorVersionConfigParams = typing.Union[
    LegacyProcessorVersionConfig_ClassifyParams,
    LegacyProcessorVersionConfig_ExtractParams,
    LegacyProcessorVersionConfig_SplitterParams,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .extraction_field_result_reference_bounding_boxes_item import ExtractionFieldResultReferenceBoundingBoxesItemParams


class ExtractionFieldResultReferenceParams(typing_extensions.TypedDict):
    id: str
    """
    The unique identifier for this field
    """

    field_name: typing_extensions.Annotated[str, FieldMetadata(alias="fieldName")]
    """
    The name of the extracted field
    """

    page: float
    """
    The page number that this bounding box is from
    """

    bounding_boxes: typing_extensions.Annotated[
        typing.Sequence[ExtractionFieldResultReferenceBoundingBoxesItemParams], FieldMetadata(alias="boundingBoxes")
    ]
    """
    The bounding boxes of the field
    """



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel, UnionMetadata
from ...types.json_object import JsonObject
from ...types.legacy_classification import LegacyClassification
from ...types.legacy_classification_advanced_options import LegacyClassificationAdvancedOptions
from ...types.legacy_classification_config_base_processor import LegacyClassificationConfigBaseProcessor
from ...types.legacy_extraction_advanced_options import LegacyExtractionAdvancedOptions
from ...types.legacy_extraction_config_base_processor import LegacyExtractionConfigBaseProcessor
from ...types.legacy_splitter_advanced_options import LegacySplitterAdvancedOptions
from ...types.legacy_splitter_config_base_processor import LegacySplitterConfigBaseProcessor
from ...types.parse_config import ParseConfig


class ProcessorRunCreateRequestConfig_Classify(UncheckedBaseModel):
    """
    The configuration for the processor run. If this is provided, this config will be used. If not provided, the config for the specific version you provide will be used. The type of configuration must match the processor type.
    """

    type: typing.Literal["CLASSIFY"] = "CLASSIFY"
    base_processor: typing_extensions.Annotated[
        typing.Optional[LegacyClassificationConfigBaseProcessor], FieldMetadata(alias="baseProcessor")
    ] = pydantic.Field(alias="baseProcessor", default=None)
    base_version: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseVersion")] = (
        pydantic.Field(alias="baseVersion", default=None)
    )
    classifications: typing.List[LegacyClassification]
    classification_rules: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="classificationRules")
    ] = pydantic.Field(alias="classificationRules", default=None)
    advanced_options: typing_extensions.Annotated[
        typing.Optional[LegacyClassificationAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = pydantic.Field(alias="advancedOptions", default=None)
    parser: typing.Optional[ParseConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class ProcessorRunCreateRequestConfig_Extract(UncheckedBaseModel):
    """
    The configuration for the processor run. If this is provided, this config will be used. If not provided, the config for the specific version you provide will be used. The type of configuration must match the processor type.
    """

    type: typing.Literal["EXTRACT"] = "EXTRACT"
    base_processor: typing_extensions.Annotated[
        typing.Optional[LegacyExtractionConfigBaseProcessor], FieldMetadata(alias="baseProcessor")
    ] = pydantic.Field(alias="baseProcessor", default=None)
    base_version: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseVersion")] = (
        pydantic.Field(alias="baseVersion", default=None)
    )
    extraction_rules: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="extractionRules")] = (
        pydantic.Field(alias="extractionRules", default=None)
    )
    schema_: typing_extensions.Annotated[typing.Optional[JsonObject], FieldMetadata(alias="schema")] = pydantic.Field(
        alias="schema", default=None
    )
    fields: typing.Optional[typing.List["LegacyExtractionField"]] = None
    advanced_options: typing_extensions.Annotated[
        typing.Optional[LegacyExtractionAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = pydantic.Field(alias="advancedOptions", default=None)
    parser: typing.Optional[ParseConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class ProcessorRunCreateRequestConfig_Splitter(UncheckedBaseModel):
    """
    The configuration for the processor run. If this is provided, this config will be used. If not provided, the config for the specific version you provide will be used. The type of configuration must match the processor type.
    """

    type: typing.Literal["SPLITTER"] = "SPLITTER"
    base_processor: typing_extensions.Annotated[
        typing.Optional[LegacySplitterConfigBaseProcessor], FieldMetadata(alias="baseProcessor")
    ] = pydantic.Field(alias="baseProcessor", default=None)
    base_version: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseVersion")] = (
        pydantic.Field(alias="baseVersion", default=None)
    )
    split_classifications: typing_extensions.Annotated[
        typing.List[LegacyClassification], FieldMetadata(alias="splitClassifications")
    ] = pydantic.Field(alias="splitClassifications")
    split_rules: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="splitRules")] = pydantic.Field(
        alias="splitRules", default=None
    )
    advanced_options: typing_extensions.Annotated[
        typing.Optional[LegacySplitterAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = pydantic.Field(alias="advancedOptions", default=None)
    parser: typing.Optional[ParseConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


ProcessorRunCreateRequestConfig = typing_extensions.Annotated[
    typing.Union[
        ProcessorRunCreateRequestConfig_Classify,
        ProcessorRunCreateRequestConfig_Extract,
        ProcessorRunCreateRequestConfig_Splitter,
    ],
    UnionMetadata(discriminant="type"),
]
from ...types.legacy_extraction_field import LegacyExtractionField  # noqa: E402, I001

update_forward_refs(ProcessorRunCreateRequestConfig_Extract, LegacyExtractionField=LegacyExtractionField)



# This file was auto-generated by Fern from our API Definition.

import typing

from .provided_classify_output import ProvidedClassifyOutputParams
from .provided_extract_output import ProvidedExtractOutputParams
from .provided_split_output import ProvidedSplitOutputParams

ProvidedProcessorOutputParams = typing.Union[
    ProvidedExtractOutputParams, ProvidedClassifyOutputParams, ProvidedSplitOutputParams
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .extraction_field_result import ExtractionFieldResult

ExtractOutputLegacy = typing.Dict[str, ExtractionFieldResult]



# This file was auto-generated by Fern from our API Definition.

import typing

from .legacy_provided_fields_array_output import LegacyProvidedFieldsArrayOutput
from .legacy_provided_json_output import LegacyProvidedJsonOutput

LegacyProvidedExtractionOutput = typing.Union[LegacyProvidedJsonOutput, LegacyProvidedFieldsArrayOutput]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class EditBoundingBox(UncheckedBaseModel):
    """
    Bounding box coordinates for the field location in the PDF (pixel coordinates)
    """

    left: float = pydantic.Field()
    """
    The left coordinate of the bounding box (pixels)
    """

    top: float = pydantic.Field()
    """
    The top coordinate of the bounding box (pixels)
    """

    right: float = pydantic.Field()
    """
    The right coordinate of the bounding box (pixels)
    """

    bottom: float = pydantic.Field()
    """
    The bottom coordinate of the bounding box (pixels)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.legacy_extraction_advanced_options_array_citation_strategy import (
    LegacyExtractionAdvancedOptionsArrayCitationStrategy,
)
from ..types.legacy_extraction_advanced_options_excel_sheet_selection_strategy import (
    LegacyExtractionAdvancedOptionsExcelSheetSelectionStrategy,
)
from .array_strategy import ArrayStrategyParams
from .excel_sheet_range import ExcelSheetRangeParams
from .legacy_extract_chunking_options import LegacyExtractChunkingOptionsParams
from .legacy_extraction_advanced_options_review_agent import LegacyExtractionAdvancedOptionsReviewAgentParams
from .page_ranges import PageRangesParams


class LegacyExtractionAdvancedOptionsParams(typing_extensions.TypedDict):
    document_kind: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="documentKind")]]
    """
    DEPRECATED - use extractionRules for all system prompts.
    """

    key_definitions: typing_extensions.NotRequired[
        typing_extensions.Annotated[str, FieldMetadata(alias="keyDefinitions")]
    ]
    """
    DEPRECATED - use extractionRules for all system prompts.
    """

    model_reasoning_insights_enabled: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="modelReasoningInsightsEnabled")]
    ]
    """
    Whether to enable model reasoning insights.
    """

    advanced_multimodal_enabled: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="advancedMultimodalEnabled")]
    ]
    """
    Whether to enable advanced multimodal features.
    """

    citations_enabled: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="citationsEnabled")]
    ]
    """
    Whether to enable citations in the output.
    """

    array_citation_strategy: typing_extensions.NotRequired[
        typing_extensions.Annotated[
            LegacyExtractionAdvancedOptionsArrayCitationStrategy, FieldMetadata(alias="arrayCitationStrategy")
        ]
    ]
    """
    Granularity for array citations. This requires citationsEnabled=true and a base processor version that supports property-level array citations (extraction_performance ≥ 4.4.0).
    """

    advanced_figure_parsing_enabled: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="advancedFigureParsingEnabled")]
    ]
    """
    Whether to enable advanced figure parsing.
    """

    review_agent: typing_extensions.NotRequired[
        typing_extensions.Annotated[
            LegacyExtractionAdvancedOptionsReviewAgentParams, FieldMetadata(alias="reviewAgent")
        ]
    ]
    """
    Configuration for the review agent that analyzes extraction results.
    When enabled, each field in the output metadata will include a `reviewAgentScore` (1-5)
    and may include additional `insights` of type `issue` or `review_summary` to help identify
    fields that may need manual review.
    
    To learn more, view the [Review Agent Documentation](https://docs.extend.ai/product/extraction/review-agent)
    """

    array_strategy: typing_extensions.NotRequired[
        typing_extensions.Annotated[ArrayStrategyParams, FieldMetadata(alias="arrayStrategy")]
    ]
    """
    Strategy for handling large arrays in documents.
    """

    chunking_options: typing_extensions.NotRequired[
        typing_extensions.Annotated[LegacyExtractChunkingOptionsParams, FieldMetadata(alias="chunkingOptions")]
    ]
    excel_sheet_ranges: typing_extensions.NotRequired[
        typing_extensions.Annotated[typing.Sequence[ExcelSheetRangeParams], FieldMetadata(alias="excelSheetRanges")]
    ]
    """
    Ranges of sheet indices to extract from Excel documents.
    """

    excel_sheet_selection_strategy: typing_extensions.NotRequired[
        typing_extensions.Annotated[
            LegacyExtractionAdvancedOptionsExcelSheetSelectionStrategy,
            FieldMetadata(alias="excelSheetSelectionStrategy"),
        ]
    ]
    """
    Strategy for selecting sheets from Excel documents.
    """

    fixed_page_limit: typing_extensions.NotRequired[
        typing_extensions.Annotated[int, FieldMetadata(alias="fixedPageLimit")]
    ]
    """
    DEPRECATED - See [Page Ranges](/product/page-ranges).
    """

    page_ranges: typing_extensions.NotRequired[
        typing_extensions.Annotated[PageRangesParams, FieldMetadata(alias="pageRanges")]
    ]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class EditRunOutputEditedFileParams(typing_extensions.TypedDict):
    """
    Information about the edited output file.
    """

    id: str
    """
    The ID of the edited output file.
    """

    presigned_url: typing_extensions.Annotated[str, FieldMetadata(alias="presignedUrl")]
    """
    A presigned URL to download the edited file. Expires after 15 minutes.
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class LegacyDocumentProcessorRunCreditsParams(typing_extensions.TypedDict):
    """
    These are usage credits for document processing (extraction, classification, or splitting). File parsing credits are tracked separately and can be retrieved from the [Get File](/developers/api-reference/file-endpoints/get-file) endpoint.

    This field will not be returned for processor runs created before October 7, 2025, or for customers on legacy billing systems.

    For more details on how credits work, see our [Credits Guide](/product/general/how-credits-work).
    """

    credits: float
    """
    The number of credits consumed specifically for document processing in this processor run. This does not include file parsing credits.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .parse_run_output_ocr_words_item import ParseRunOutputOcrWordsItem


class ParseRunOutputOcr(UncheckedBaseModel):
    """
    Raw OCR data from the parsing process. Only included when `returnOcr` is configured in the parse config's advanced options.
    """

    words: typing.Optional[typing.List[ParseRunOutputOcrWordsItem]] = pydantic.Field(default=None)
    """
    An array of individual words detected by OCR.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ...requests.legacy_processor_version import LegacyProcessorVersionParams


class ProcessorVersionListResponseParams(typing_extensions.TypedDict):
    success: bool
    versions: typing.Sequence[LegacyProcessorVersionParams]
    """
    An array of ProcessorVersion objects representing all versions of the specified processor.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class SortDir(enum.StrEnum):
    """
    Sort in ascending or descending order. Ascending order means the earliest result is returned first.
    """

    ASC = "asc"
    DESC = "desc"
    _UNKNOWN = "__SORTDIR_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "SortDir":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        asc: typing.Callable[[], T_Result],
        desc: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is SortDir.ASC:
            return asc()
        if self is SortDir.DESC:
            return desc()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .chunk_metadata_page_range import ChunkMetadataPageRangeParams


class ChunkMetadataParams(typing_extensions.TypedDict):
    """
    Metadata about the chunk.
    """

    page_range: typing_extensions.Annotated[ChunkMetadataPageRangeParams, FieldMetadata(alias="pageRange")]
    """
    The page range this chunk covers. Often will just be a partial page, in which cases `start` and `end` will be the same.
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...requests.legacy_processor import LegacyProcessorParams


class ProcessorCreateResponseParams(typing_extensions.TypedDict):
    success: bool
    processor: LegacyProcessorParams



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .file_summary import FileSummaryParams


class EvaluationSetItemSummaryParams(typing_extensions.TypedDict):
    object: typing.Literal["evaluation_set_item"]
    """
    The type of object. In this case, it will always be `"evaluation_set_item"`.
    """

    id: str
    """
    The ID of the evaluation set item.
    
    Example: `"evi_kR9mNP12Qw4yTv8BdR3H"`
    """

    file: FileSummaryParams
    """
    A summary of the file associated with the evaluation set item.
    """
